pub enum Augmented<T, A: Clone> {
Primary(T),
WithAux(T, A),
}Expand description
An Augmented value is a generic wrapper that holds a primary value of type T and an
optional auxiliary value of type A.
This is useful when a function needs to return a value that has some additional, optional
context attached to it. For example, A can be used to override some of the fields of T
without modifying T itself.
Variants
Primary(T)
The primary value, without any auxiliary data.
WithAux(T, A)
The primary value, with auxiliary data.
Implementations
Sourceimpl<T, A: Clone> Augmented<T, A>
impl<T, A: Clone> Augmented<T, A>
Sourcepub fn map<U>(self, f: impl FnOnce(T) -> U) -> Augmented<U, A>
pub fn map<U>(self, f: impl FnOnce(T) -> U) -> Augmented<U, A>
Maps an Augmented<T, A> to an Augmented<U, A> by applying a function to the contained
primary value, leaving the auxiliary value untouched.