pub struct ReleaseGuard<T> { /* private fields */ }Expand description
A wrapper a round a Releasable object that will check, in test and when assertion are enabled, that the value has been released before being dropped.
Implementations
Sourceimpl<T> ReleaseGuard<T>
impl<T> ReleaseGuard<T>
Sourcepub fn take(this: ReleaseGuard<T>) -> T
pub fn take(this: ReleaseGuard<T>) -> T
Disarm this release guard.
This will prevent any runtime check that the value has been correctly released.